@@ -154,7 +154,7 @@ time by ::
 
     ts = obs.ts_bow + datetime.timedelta(seconds=obs.t[k])
 
-When a navigation file is read in the same command as an observation object, the
+When a navigation file is read in the same command as an observation file, the
 observation object will get an additional attribute called `ephs`.  So, to get
 the `C1` pseudorange and corresponding ephemeris for space vehicle `j` at time
 `k`, we would do ::
@@ -438,6 +438,7 @@ class NavG:
             # Get the label.
             label = line[60:80]
 
+            # State machine
             if state == STATE_INIT:
                 if label != "RINEX VERSION / TYPE":
                     raise Exception("rnx: expected version in first line!")
@@ -569,7 +570,7 @@ class Obs:
     pos : (3,) float np.ndarray
         ECEF position coordinates from the RINEX file.
     tz_approx : int
-        Approximate time zone offset based only on the longitude.
+        Approximate time zone offset based only on the longitude [hr].
     ts_bow : datetime.datetime
         Date and timestamp of the beginning of the week based on the earliest
         observation in the file.
@@ -578,7 +579,9 @@ class Obs:
     len : int
         Number of points in time.
     t : (K,) float np.ndarray
-        Array of K time values since beginning of GPS week in seconds.
+        Array of K receiver time values since beginning of GPS week in seconds.
+    T_os : (K,) float np.ndarray
+        Array of K receiver clock offsets in seconds.
     events : (K,) int np.ndarray
         Event flags (integers from 0 to 6), a row per moment in time.
     sys : (J,) str np.ndarray
@@ -685,14 +688,16 @@ class Obs:
         ts_bow = None               # timestamp of beginning of week
         n_line = 0                  # RINEX file line number (base 1)
         t = None                    # times of week [s] for each epoch
-        svs = None                  # space vehicle labels for each epoch
+        T_os = None                 # receiver clock offsets [s] for each epoch
         events = None               # event flags for each epoch
+        svs = None                  # space vehicle labels for each epoch
         data = None                 # matrix of observations
         data_space = SPACE_SIZE     # rows allocated to `data` matrix
         data_rows = 0               # rows used in `data` matrix
 
         # epoch-level variables
         ts_epoch = None             # timestamp of an epoch
+        T_os_epoch = 0.0            # receiver clock offset [s]
         types_epoch_left = 0        # observation types left for an epoch
         event_epoch = 0             # the epoch flag (integer from 0 to 6)
         svs_epoch_cnt = 0           # number of space vehicles in epoch
@@ -720,6 +725,7 @@ class Obs:
             # Get the label.
             label = line[60:80]
 
+            # State machine
             if state == STATE_INIT:
                 if label != "RINEX VERSION / TYPE":
                     raise Exception("rnx: expected version in first line!")
@@ -761,8 +767,9 @@ class Obs:
 
                     # Initialize time, svs, and observation data matrix.
                     t = np.zeros(data_space, dtype=float)
-                    svs = np.empty(data_space, dtype="U3")
+                    T_os = np.zeros(SPACE_SIZE, dtype=float)
                     events = np.zeros(data_space, dtype=int)
+                    svs = np.empty(data_space, dtype="U3")
                     data = np.full((data_space, types_cnt), FILLER)
 
                     # Decide if more observation types need to be read.
@@ -805,11 +812,6 @@ class Obs:
                     state = STATE_EPOCH
                     continue
 
-                # Read the epoch flag.
-                if int(line[28]) != 0:
-                    state = STATE_EPOCH
-                    continue
-
                 # Read the date and time as a timestamp.
                 year = int(line[1:3])
                 year += 2000 if year < 80 else 1900
@@ -842,6 +844,12 @@ class Obs:
                         svs_epoch_list[n] = line[m:(m + 3)]
                     svs_epoch_left -= 1
 
+                # Receiver clock offset [s]
+                if line[68:80].isspace():
+                    T_os_epoch = 0.0
+                else:
+                    T_os_epoch = float(line[68:80])
+
                 # Decide if more space vehicle PRNs need to be read.
                 if svs_epoch_left > 0:
                     state = STATE_MORE_SVS
@@ -896,11 +904,13 @@ class Obs:
                     # Add rows to the data space if needed.
                     if data_rows + svs_epoch_cnt >= data_space:
                         t = np.concatenate((t,
-                                np.zeros((SPACE_SIZE,), dtype=float)))
-                        svs = np.concatenate((svs,
-                                np.empty((SPACE_SIZE,), dtype="U3")))
+                                np.zeros(SPACE_SIZE, dtype=float)))
+                        T_os = np.concatenate((T_os,
+                                np.zeros(SPACE_SIZE, dtype=float)))
                         events = np.concatenate((events,
-                                np.zeros((SPACE_SIZE,), dtype=int)))
+                                np.zeros(SPACE_SIZE, dtype=int)))
+                        svs = np.concatenate((svs,
+                                np.empty(SPACE_SIZE, dtype="U3")))
                         data = np.vstack((data,
                                 np.full((SPACE_SIZE, types_cnt), FILLER)))
                         data_space += SPACE_SIZE
@@ -917,8 +927,9 @@ class Obs:
                     # Store the time, space vehicle label, and observations.
                     for n_sv in range(svs_epoch_cnt):
                         t[data_rows] = t_rx_epoch
-                        svs[data_rows] = svs_epoch_list[n_sv]
+                        T_os[data_rows] = T_os_epoch
                         events[data_rows] = event_epoch
+                        svs[data_rows] = svs_epoch_list[n_sv]
                         data[data_rows, :] = obs_epoch_list[ma:mb]
                         data_rows += 1
                         ma = mb
@@ -932,8 +943,9 @@ class Obs:
 
         # Drop the extra space.
         t = t[:data_rows]
-        svs = svs[:data_rows]
+        T_os = T_os[:data_rows]
         events = events[:data_rows]
+        svs = svs[:data_rows]
         data = data[:data_rows, :]
 
         # Remove unused observation types (columns of `data`).
@@ -948,7 +960,8 @@ class Obs:
         K = len(t)
         J = len(svs)
 
-        # Keep only one event flag per moment in time.
+        # Keep only one clock offset and event flag per moment in time.
+        T_os = T_os[ii]
         events = events[ii]
 
         # Build objects with the observation data matrix, one object for each
@@ -989,6 +1002,7 @@ class Obs:
         self.types = types_list.copy()
         self.len = len(t)
         self.t = t.copy()
+        self.T_os = T_os.copy()
         self.events = events.copy()
         self.sys = sys.copy()
         self.prns = prns.copy()
@@ -1010,7 +1024,7 @@ def read(file_one, file_two=None, file_ref=None):
     ----------
     file_one : str
         Name of first RINEX file.  Can be a navigation or an observation file.
-    file_two : str
+    file_two : str, default None
         Name of second RINEX file.  Can be a navigation or an observation file.
     file_ref : str, default None
         Name of reference RINEX observation file.
